import { useCallback } from 'react';
import { DesktopLayout } from './layouts/DesktopLayout';
import { MobileLayout } from './layouts/MobileLayout';
import { UserSelection } from './components/UserSelection';
import { useTaskDataOptimized } from './hooks/useTaskDataOptimized';
import { useDeviceType } from './hooks/useDeviceType';
import { useUserSelection } from './hooks/useUserSelection';
import './App.css';

export function App() {
  const { selectedUser, users, selectUser } = useUserSelection();
  const deviceType = useDeviceType();
  const {
    loading,
    groups,
    step,
    selectedGroup,
    selectedTask,
    selectedStep,
    setSelectedGroup,
    setSelectedTask,
    setSelectedStep,
    handlePrintTask,
    handlePrintStep,
    handleAddNote
  } = useTaskDataOptimized();

  const handleBack = useCallback(() => {
    if (selectedStep) {
      setSelectedStep(undefined);
    } else if (selectedTask) {
      setSelectedTask(undefined);
    } else if (selectedGroup) {
      setSelectedGroup(undefined);
    }
  }, [selectedStep, selectedTask, selectedGroup, setSelectedStep, setSelectedTask, setSelectedGroup]);

  console.log('App render:', {
    selectedUser,
    deviceType,
    loading,
    groups,
    step,
    selectedGroup,
    selectedTask,
    selectedStep
  });

  console.log('App rendering main content, conditions:', {
    hasUser: selectedUser !== null,
    deviceType,
    hasGroups: groups.length > 0,
    hasStep: step !== null
  });

  if (!selectedUser) {
    return (
      <div className="app">
        <UserSelection users={users} onSelectUser={selectUser} />
      </div>
    );
  }

  return (
    <div className="app">
      {deviceType === 'desktop' ? (
        <DesktopLayout
          groups={groups}
          selectedGroup={selectedGroup}
          selectedTask={selectedTask}
          selectedStep={selectedStep}
          onGroupSelect={setSelectedGroup}
          onTaskSelect={setSelectedTask}
          onStepSelect={setSelectedStep}
          onPrintTask={handlePrintTask}
          onPrintStep={handlePrintStep}
          onAddNote={handleAddNote}
        />
      ) : (
        <MobileLayout
          groups={groups}
          selectedGroup={selectedGroup}
          selectedTask={selectedTask}
          selectedStep={selectedStep}
          onGroupSelect={setSelectedGroup}
          onTaskSelect={setSelectedTask}
          onStepSelect={setSelectedStep}
          onBack={handleBack}
          onPrintTask={handlePrintTask}
          onPrintStep={handlePrintStep}
          onAddNote={handleAddNote}
        />
      )}
    </div>
  );
}
