import { useState, useCallback, useEffect } from 'react';

interface User {
  id: number;
  name: string;
}

const DEFAULT_USER: User = {
  id: 1,
  name: 'Test User'
};

export const useUserSelection = () => {
  const [selectedUser, setSelectedUser] = useState<User | null>(() => {
    // Try to load from localStorage first
    const storedUser = localStorage.getItem('selectedUser');
    if (storedUser) {
      try {
        return JSON.parse(storedUser);
      } catch (e) {
        console.error('Error parsing stored user:', e);
      }
    }
    // Start with no user selected
    return null;
  });

  useEffect(() => {
    console.log('useUserSelection: selectedUser changed:', selectedUser);
  }, [selectedUser]);

  const users = [DEFAULT_USER];

  const selectUser = useCallback((user: User) => {
    console.log('Selecting user:', user);
    setSelectedUser(user);
    localStorage.setItem('selectedUser', JSON.stringify(user));
  }, []);

  return {
    selectedUser,
    users,
    selectUser
  };
};